==> bw-util-jms-4.0.5-sources.jar: org/bedework/util/jms/events/TimedEvent.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.bedework.util.jms.events;

import org.bedework.util.misc.ToString;

/** An event for some timed activity. The label identifies the event
 *
 * @author Mike Douglass
 */
public class TimedEvent extends SysEvent implements MillisecsEvent {
  private static final long serialVersionUID = 1L;

  private String label;

  private long millis;

  /** Constructor
   *
   * @param code
   * @param label
   * @param millis - time for stats - e.g. time to process login
   */
  public TimedEvent(final String code,
                    final String label,
                    final long millis) {
    super(code);

    this.label = label;
    this.millis = millis;
  }

  /**
   *
   * @return label
   */
  public String getLabel() {
    return label;
  }

  @Override
  public long getMillis() {
    return millis;
  }

  @Override
  public void toStringSegment(final ToString ts) {
    super.toStringSegment(ts);

    ts.append("label", getLabel());
    ts.append("millis", getMillis());
  }
}

==> bw-util-jms-5.0.7-sources.jar: org/bedework/util/jms/events/TimedEvent.java <==
/* ********************************************************************
    Licensed to Jasig under one or more contributor license
    agreements. See the NOTICE file distributed with this work
    for additional information regarding copyright ownership.
    Jasig licenses this file to you under the Apache License,
    Version 2.0 (the "License"); you may not use this file
    except in compliance with the License. You may obtain a
    copy of the License at:

    http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on
    an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied. See the License for the
    specific language governing permissions and limitations
    under the License.
*/
package org.bedework.util.jms.events;

import org.bedework.util.misc.ToString;

/** An event for some timed activity. The label identifies the event
 *
 * @author Mike Douglass
 */
public class TimedEvent extends SysEvent implements MillisecsEvent {
  private static final long serialVersionUID = 1L;

  private final String label;

  private final long millis;

  /** Constructor
   *
   * @param code identifier
   * @param label for event
   * @param millis - time for stats - e.g. time to process login
   */
  public TimedEvent(final String code,
                    final String label,
                    final long millis) {
    super(code);

    this.label = label;
    this.millis = millis;
  }

  /**
   *
   * @return label
   */
  public String getLabel() {
    return label;
  }

  @Override
  public long getMillis() {
    return millis;
  }

  @Override
  public void toStringSegment(final ToString ts) {
    super.toStringSegment(ts);

    ts.append("label", getLabel());
    ts.append("millis", getMillis());
  }
}
